alloc_instance_data_buffer

Function alloc_instance_data_buffer 

pub fn alloc_instance_data_buffer(
    idb: &mut InstanceDataBuffer,
    num: u32,
    stride: u16,
)
  • idb: InstanceDataBuffer structure will be filled, and will be valid for duration of frame, and can be reused for multiple draw calls.
  • num: Number of instances.
  • stride: Instance stride. Must be multiple of 16.